SVB Bindings for Python
=======================

A Python library for SVB's Banking API.


Setup
-----

You can install this package by using the pip tool and installing:

    $ pip install svb

Or:

    $ easy_install svb


Setting up a SVB Account
---------------------------

Contact us at SVB!

Using the SVB API
--------------------

Documentation for the python bindings can be found alongside SVB's other bindings here:

- http://docs.svbplatform.com/
